==> musashi-core-1.0.3.tar.gz: musashi-core-1.0.3/help/en/xtjoinHelp.h <==

#include "commonHelp.h"
/*============================================================================*/
/* ޥɥإ,man,musahi GUI ̥å                           */
/*============================================================================*/
/*----------------------------------------------------------------------------*/
/* ޥɤΥȥ                                                         */
/* ޥɥإפκǽιԤɽ                                             */
/*----------------------------------------------------------------------------*/
#define HELPT "join fields of a reference file"

/*----------------------------------------------------------------------------*/
/* ѥ᡼                                                                 */
/* ޥɥإפ USAGE:Ȥ" XXXT"ɽ ex)-k ̾ꥹ*/
/* flagΥץϥޥɥإפOPTIONS)Ȥɽ ex)-z : ɸϤΰ*/
/*----------------------------------------------------------------------------*/
/*-k*/
#define TKYT "list of attributes"
#define TKYC "a list of attributes based on which join is done (mandatory)"

/*-K*/
#define MKYT "list of attributes"
#define MKYC "a list of attributes of a reference file. This is used when the attribute names of a reference file are different from those of an input file specified by -k."

/*-m*/
#define MSTT "reference file"
#define MSTC "reference file name"

/*-f*/
#define FLDT "list of attributes"
#define FLDC "the  attribute of a reference file which is joined with an input file"
#define FLDF NULL

/*-n*/
#define TNLT "input data not matched"
#define TNLC "flag indicating that input data which does not match the reference file is also output"

/*-N*/
#define MNLT "reference data not matched"
#define MNLC "flag indicating that data of a reference file which does not match the input file is also output"

/*-H*/
#define HAST "hash join"
#define HASC "hash join is performed with this option"

/*-i*/
#define INFT C_INFT
#define INFC C_INFC

/*-o*/
#define OTFT C_OTFT
#define OTFC C_OTFC

/*-z*/
#define ZIPT C_ZIPT
#define ZIPC C_ZIPC

/*-t*/
#define TXTT C_TXTT
#define TXTC C_TXTC

/*-T*/
#define TMPT C_TMPT
#define TMPC C_TMPC

/*----------------------------------------------------------------------------*/
/*                                                                        */
/* ޥɥإפSUMMARY:Ȥɽ                                     */
/* HTMLإפmanˤϡHELPDξ˷礹ɽ                   */
/*----------------------------------------------------------------------------*/
#define HELPS " Comparing the value of the attribute of an input file specified by -k with that of a reference file specified by -K,  if they are the same, this command joins attributes of a reference file specified by -f with an input file."

/*----------------------------------------------------------------------------*/
/*                                                                          */
/*----------------------------------------------------------------------------*/
#define HELPE "\
xtjoin -k customerID -m ref.xt -f birthday,gender -i dat.xt -o rsl.xt\n\
xtjoin -k customerID -m ref.xt -f birthday,gender -nN -i dat.xt -o rsl.xt\n\
"

/*----------------------------------------------------------------------------*/
/* ȥޥ(ɬޤǶڤꡢѤʤ)                           */
/*----------------------------------------------------------------------------*/
#define HELPR "xtnjoin,xtproduct,xtcommon"

/*----------------------------------------------------------------------------*/
/* ԤˤĤ                                                               */
/* ޥɥإפˤɽʤ                                             */
/*----------------------------------------------------------------------------*/
#define HELPA C_HELPA

/*----------------------------------------------------------------------------*/
/* Хݡ                                                               */
/* ϿХޥɥإפBUG REPORT:ɽ롣                  */
/* Ͽʤ(#define HELPB "")ɽʤ                           */
/*----------------------------------------------------------------------------*/
#define HELPB C_HELPB

/*----------------------------------------------------------------------------*/
/* ۡڡ                                                               */
/* ϿХޥɥإפINFORMATION:ɽ롣                 */
/* Ͽʤ(#define HELPH "")ɽʤ                           */
/*----------------------------------------------------------------------------*/
#define HELPH C_HELPH

==> musashi-core-1.0.4.tar.gz: musashi-core-1.0.4/help/en/xtjoinHelp.h <==
#include "commonHelp.h"
/*============================================================================*/
/* Management of messages common to command help, man, and musashi GUI                           */
/*============================================================================*/
/*----------------------------------------------------------------------------*/
/* ޥɤΥȥ                                                         */
/* ޥɥإפκǽιԤɽ                                             */
/*----------------------------------------------------------------------------*/
#define HELPT "join fields of a reference file"

/*----------------------------------------------------------------------------*/
/* ѥ᡼                                                                 */
/* ޥɥإפ USAGE:Ȥ" XXXT"ɽ ex)-k ̾ꥹ*/
/* flagΥץϥޥɥإפOPTIONS)Ȥɽ ex)-z : ɸϤΰ*/
/*----------------------------------------------------------------------------*/
/*-k*/
#define TKYT "list of attributes"
#define TKYC "a list of attributes based on which join is done (mandatory)"

/*-K*/
#define MKYT "list of attributes"
#define MKYC "a list of attributes of a reference file. This is used when the attribute names of a reference file are different from those of an input file specified by -k."

/*-m*/
#define MSTT "reference file"
#define MSTC "reference file name"

/*-f*/
#define FLDT "list of attributes"
#define FLDC "the  attribute of a reference file which is joined with an input file"
#define FLDF NULL

/*-n*/
#define TNLT "input data not matched"
#define TNLC "flag indicating that input data which does not match the reference file is also output"

/*-N*/
#define MNLT "reference data not matched"
#define MNLC "flag indicating that data of a reference file which does not match the input file is also output"

/*-H*/
#define HAST "hash join"
#define HASC "hash join is performed with this option"

/*-i*/
#define INFT C_INFT
#define INFC C_INFC

/*-o*/
#define OTFT C_OTFT
#define OTFC C_OTFC

/*-z*/
#define ZIPT C_ZIPT
#define ZIPC C_ZIPC

/*-t*/
#define TXTT C_TXTT
#define TXTC C_TXTC

/*-T*/
#define TMPT C_TMPT
#define TMPC C_TMPC

/*----------------------------------------------------------------------------*/
/*                                                                        */
/* ޥɥإפSUMMARY:Ȥɽ                                     */
/* HTMLإפmanˤϡHELPDξ˷礹ɽ                   */
/*----------------------------------------------------------------------------*/
#define HELPS " This command joins the attribute(s) from the reference file to an input file with a common key attribute present in both files. You need not define the key attribute in the reference file with option -K if the key attribute name is the same in both the reference file and input file. If the attribute name of the field in the reference file to be joined exist in the input file, you may rename it with ':' (e.g. -f attribute name:new attribute name). Note that the value of the key attribute at -K must be unique, alternatively, you can use xtnjoin for inner joins. A outer join can be performed with the option -n which joins all rows from the reference file to the input file. When hash join is performed between the reference file and the input file, the output will not be sorted if the input file is not sorted by key attribute -k . "

/*----------------------------------------------------------------------------*/
/*                                                                          */
/*----------------------------------------------------------------------------*/
#define HELPE "\
xtjoin -k customerID -m ref.xt -f birthday,gender -i dat.xt -o rsl.xt\n\
xtjoin -k customerID -m ref.xt -f birthday,gender -nN -i dat.xt -o rsl.xt\n\
"

/*----------------------------------------------------------------------------*/
/* ȥޥ(ɬޤǶڤꡢѤʤ)                           */
/*----------------------------------------------------------------------------*/
#define HELPR "xtnjoin,xtproduct,xtcommon"

/*----------------------------------------------------------------------------*/
/* ԤˤĤ                                                               */
/* ޥɥإפˤɽʤ                                             */
/*----------------------------------------------------------------------------*/
#define HELPA C_HELPA

/*----------------------------------------------------------------------------*/
/* Хݡ                                                               */
/* ϿХޥɥإפBUG REPORT:ɽ롣                  */
/* Ͽʤ(#define HELPB "")ɽʤ                           */
/*----------------------------------------------------------------------------*/
#define HELPB C_HELPB

/*----------------------------------------------------------------------------*/
/* ۡڡ                                                               */
/* ϿХޥɥإפINFORMATION:ɽ롣                 */
/* Ͽʤ(#define HELPH "")ɽʤ                           */
/*----------------------------------------------------------------------------*/
#define HELPH C_HELPH
